=== modified file 'tests/dbqp.py'
--- tests/dbqp.py	2011-02-04 20:41:08 +0000
+++ tests/dbqp.py	2011-02-09 17:41:08 +0000
@@ -84,3 +84,12 @@
     if server_manager and not variables['startandexit']:
         server_manager.cleanup()
 
+    if not variables['startandexit']:
+        if test_manager:
+            fail_count = test_manager.has_failing_tests()
+            sys.exit(test_manager.has_failing_tests())
+        else:
+            # return 1 as we likely have a problem if we don't have a
+            # test_manager
+            sys.exit(1)
+

=== added directory 'tests/dbqp_data'
=== modified file 'tests/include.am'
--- tests/include.am	2011-02-09 16:43:26 +0000
+++ tests/include.am	2011-02-10 18:34:13 +0000
@@ -155,7 +155,8 @@
 
 nukevar:
 	rm -rf tests/var \
-        rm -rf tests/dbqp_work 
+        rm -rf tests/dbqp_work \
+        rm tests/dbqp_data/*
  
 
 .PHONY: nukevar

=== modified file 'tests/lib/drizzle_test_run/dtr_test_execution.py'
--- tests/lib/drizzle_test_run/dtr_test_execution.py	2011-02-07 22:20:03 +0000
+++ tests/lib/drizzle_test_run/dtr_test_execution.py	2011-02-10 02:05:07 +0000
@@ -116,7 +116,7 @@
 
         drizzletest_output.close()
         drizzletest_file = open(drizzletest_outfile,'r')
-        output = str(drizzletest_file.readlines())
+        output = ''.join(drizzletest_file.readlines())
         drizzletest_file.close()
 
         if self.debug:

=== modified file 'tests/lib/sys_mgmt/system_management.py'
--- tests/lib/sys_mgmt/system_management.py	2011-02-07 23:36:56 +0000
+++ tests/lib/sys_mgmt/system_management.py	2011-02-09 17:41:08 +0000
@@ -34,6 +34,7 @@
 import os
 import sys
 import copy
+from uuid import uuid4
 import shutil
 import getpass
 import commands
@@ -67,8 +68,8 @@
         self.shm_path = self.find_path(["/dev/shm", "/tmp"], required=0)
         self.cur_os = os.uname()[0]
         self.cur_user = getpass.getuser()
-        self.symlink_name = 'dbqp_workdir_%s' %(self.cur_user)
         self.workdir = os.path.abspath(variables['workdir'])
+        self.datadir = os.path.abspath(os.path.join(variables['testdir'],'dbqp_data'))
         self.top_srcdir = os.path.abspath(variables['topsrcdir'])
         self.top_builddir = os.path.abspath(variables['topbuilddir'])
         self.start_dirty = variables['startdirty']
@@ -80,8 +81,7 @@
         
         self.port_manager = portManager(self,variables['debug'])
         self.time_manager = timeManager(self)
-       
-            
+                   
         # Make sure the tree we are testing looks good
         self.code_tree = self.get_code_tree(variables, tree_type)
 
@@ -115,6 +115,15 @@
         # self.process_environment_reqs(self.environment_reqs)
         self.update_environment_vars(self.environment_reqs)
 
+        # We find or generate our id file
+        # We use a uuid to identify the symlinked
+        # workdirs.  That way, each installation
+        # Will have a uuid/tmpfs workingdir
+        # We store in a file so we know what
+        # is ours
+        self.uuid = self.get_uuid()
+        self.symlink_name = 'dbqp_workdir_%s_%s' %(self.cur_user, self.uuid)
+
         # initialize our workdir
         self.process_workdir()
 
@@ -125,12 +134,9 @@
         if self.valgrind:
             self.handle_valgrind_reqs(variables['valgrindarglist'])
             
-
         if self.debug:
             self.logging.debug_class(self)
         
-
-
     def get_code_tree(self, variables, tree_type):
         """Find out the important files, directories, and env. vars
            for a particular type of tree.  We import a definition module
@@ -145,8 +151,6 @@
         test_tree = self.process_tree_type(tree_type, variables)
         return test_tree
 
-    
-
     def process_tree_type(self, tree_type, variables):
         """Import the appropriate module depending on the type of tree
            we are testing. 
@@ -154,6 +158,7 @@
            Drizzle is the only supported type currently
 
         """
+
         if self.verbose:
             self.logging.verbose("Processing source tree under test...")
         if tree_type == 'drizzle':
@@ -165,15 +170,7 @@
             self.logging.error("Tree_type: %s not supported yet" %(tree_type))
             sys.exit(1)        
 
-    def get_port_block(self, requester, base_port, block_size):
-        """ Try to assign a block of ports for test execution
-            purposes
-
-        """
-     
-        return self.port_manager.get_port_block( requester
-                                               , base_port, block_size)
-
+    
     def create_dirset(self, rootdir, dirset):
         """ We produce the set of directories defined in dirset
             dirset is a set of dictionaries like
@@ -201,6 +198,28 @@
 
         return full_path    
 
+    def get_uuid(self):
+        """ We look to see if a uuid file exists
+            If so, we use that to know where to work
+            If not we produce one so future runs
+            have a definitive id to use
+
+        """
+
+        uuid_file_name = os.path.join(self.datadir, 'uuid')
+        if os.path.exists(uuid_file_name):
+            uuid_file = open(uuid_file_name,'r')
+            uuid = uuid_file.readline().strip()
+            uuid_file.close()
+        else:
+            uuid = uuid4()
+            print uuid
+            print uuid4()
+            uuid_file = open(uuid_file_name,'w')
+            uuid_file.write(str(uuid))
+            uuid_file.close()
+        return uuid
+
     def process_workdir(self):
         """ We create our workdir, analyze relevant variables
             to see if we should/shouldn't symlink to shm

=== modified file 'tests/lib/test_mgmt/test_management.py'
--- tests/lib/test_mgmt/test_management.py	2011-02-04 20:41:08 +0000
+++ tests/lib/test_mgmt/test_management.py	2011-02-09 17:41:08 +0000
@@ -290,3 +290,6 @@
   
         self.logging.verbose("Reordering testcases to optimize test execution...")
 
+    def has_failing_tests(self):
+        return (self.get_count_by_status('fail') + self.get_count_by_status('timeout'))
+

